-- LDAP ASN1 Schema Definitions
-- Novell Inc.
-- 122 East 1700 South
-- Provo, UT 84606-6194

-- VeRsIoN=SKADSBeta 1.0
-- CoPyRiGhT=(c) Copyright 1998, Novell, Inc.  All rights reserved

-- Schema Source:            ldap.sch
-- Description:
-- %version:             35 %
-- %created_by:          jimse %
-- %date_modified:       Tue Jun 12 22:31:27 2001 %

-- Object ID Syntax
------------------------------------------
------------------------------------------
-- ASN1 Object ID's Defined as Follows:
--     joint-iso-ccitt(2) country(16) us(840) organization(1)
--     Novell(113719) applications(1) NDS(1)  NDSAttributeType(4)
--                                            NDSAttributeSyntax(5)
--                                            NDSObjectClass(6)
--              revision number(1) sequence number(1)
------------------------------------------
-- One Additional Digit was added before the attribute or object
-- identifier to identify the release number.  This number reflects
-- the release number in which the object or attribute was added to the
-- definition.  The first release would have the ID 1 and count up from
-- there.
-- An example of the attribute of the first revision with sequence 1 would be:
-- 2 16 840 1 113719 1 1 4 1 1.
-- The attribute of the third revision with sequence 4 would be:
-- 2 16 840 1 113719 1 1 4 3 4.
------------------------------------------


LDAPSchemaExtentions DEFINITIONS ::=
BEGIN

------------------------------------------
-- Specific New attributes for LDAP services
------------------------------------------
"dn" ATTRIBUTE ::=
{
	SyntaxID	SYN_DIST_NAME,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 5 4 49}
}

-- RFC 1274
-- "EmployeeNumber" (defined in May, 1998 for Beta ?? before NetWare 5 release) has integer flag ..
-- .. , single value, and bad OID.
-- "Employee ID" (defined in NetWare 5 and Support Pack 1) is a single value attribute with bad OID.
-- The following definition has correct syntax, flags, and OID for NetWare 5 NDS v8 (SKADS).
"NSCP:employeeNumber" ATTRIBUTE ::=
{
	SyntaxID		SYN_CI_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113730 3 1 3}
}

"LDAP Host Server" ATTRIBUTE ::=
{
	SyntaxID    SYN_DIST_NAME,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 1}
}

"LDAP Group" ATTRIBUTE ::=
{
	SyntaxID    SYN_DIST_NAME,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 2}
}

"LDAP Log Level" ATTRIBUTE ::=
{
	SyntaxID    SYN_INTEGER,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  0,
	UpperBound  32768,
	ASN1ObjID   {2 16 840 1 113719 1 1 4 1 1 192}
}

"LDAP Screen Level" ATTRIBUTE ::=
{
	SyntaxID    SYN_INTEGER,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  0,
	UpperBound  32768,
	ASN1ObjID   {2 16 840 1 113719 1 27 4 3}
}

"LDAP Server Bind Limit" ATTRIBUTE ::=
{
	SyntaxID    SYN_INTEGER,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  0,
	UpperBound  4294967295,
	ASN1ObjID   {2 16 840 1 113719 1 27 4 6}
}

"LDAP Server Idle Timeout" ATTRIBUTE ::=
{
	SyntaxID    SYN_INTEGER,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  0,
	UpperBound  4294967295,
	ASN1ObjID   {2 16 840 1 113719 1 27 4 7}
}

"LDAP Enable TCP" ATTRIBUTE ::=
{
	SyntaxID    SYN_BOOLEAN,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 8}
}

"LDAP Enable UDP" ATTRIBUTE ::=
{
	SyntaxID    SYN_BOOLEAN,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 9}
}

"LDAP Enable SSL" ATTRIBUTE ::=
{
	SyntaxID    SYN_BOOLEAN,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 10}
}

"LDAP TCP Port" ATTRIBUTE ::=
{
	SyntaxID    SYN_INTEGER,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  0,
	UpperBound  65535,
	ASN1ObjID   {2 16 840 1 113719 1 27 4 11}
}

"LDAP UDP Port" ATTRIBUTE ::=
{
	SyntaxID    SYN_INTEGER,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  0,
	UpperBound  65535,
	ASN1ObjID   {2 16 840 1 113719 1 27 4 12}
}

"LDAP SSL Port" ATTRIBUTE ::=
{
	SyntaxID    SYN_INTEGER,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  0,
	UpperBound  65535,
	ASN1ObjID   {2 16 840 1 113719 1 27 4 13}
}

"LDAP Log Filename" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_STRING_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 1 4 1 204}
}

"LDAP Backup Log Filename" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_STRING_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 1 4 1 205}
}

"LDAP Log Size Limit" ATTRIBUTE ::=
{
	SyntaxID    SYN_INTEGER,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  2048,
	UpperBound  4294967295,
	ASN1ObjID   {2 16 840 1 113719 1 1 4 1 206}
}

"LDAP:keyMaterialName" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_STRING_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 22}
}

"ldapEnablePSearch" ATTRIBUTE ::=
{
	SyntaxID    SYN_BOOLEAN,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 62}
}

"ldapMaximumPSearchOperations" ATTRIBUTE ::=
{
	SyntaxID    SYN_INTEGER,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 63}
}

"ldapIgnorePSearchLimitsForEvents" ATTRIBUTE ::=
{
	SyntaxID    SYN_BOOLEAN,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 64}
}

-- Attributes for LDAP Group class
"LDAP Suffix" ATTRIBUTE ::=
{
	SyntaxID    SYN_DIST_NAME,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 1 4 1 207}
}

"LDAP Referral" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_STRING_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 14}
}

"LDAP Server List" ATTRIBUTE ::=
{
	SyntaxID    SYN_DIST_NAME,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 15}
}


"LDAP ACL v11" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE, DS_SINGLE_VALUED_ATTR},
	ASN1ObjID   {2 16 840 1 113719 1 1 4 1 210}
}


"LDAP Attribute Map v11" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE, DS_SINGLE_VALUED_ATTR},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 16}
}

"LDAP Class Map v11" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE, DS_SINGLE_VALUED_ATTR},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 17}
}

"ldapAttributeList" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_LIST,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 52}
}

"ldapClassList" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_LIST,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 53}
}

"transitionGroupDN" ATTRIBUTE ::=
{
	SyntaxID	SYN_DIST_NAME,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 56}
}

"LDAP Allow Clear Text Password" ATTRIBUTE ::=
{
	SyntaxID    SYN_BOOLEAN,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 18}
}

"LDAP Anonymous Identity" ATTRIBUTE ::=
{
	SyntaxID    SYN_DIST_NAME,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 19}
}

-- RFC 1777
-- LDAP server implementation
"searchSizeLimit" ATTRIBUTE ::=
{
	SyntaxID    SYN_INTEGER,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  0,
	UpperBound  2147483647,
	ASN1ObjID   {2 16 840 1 113719 1 27 4 4}
}

"searchTimeLimit" ATTRIBUTE ::=
{
	SyntaxID    SYN_INTEGER,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  0,
	UpperBound  2147483647,
	ASN1ObjID   {2 16 840 1 113719 1 27 4 5}
}

------------------------------------------
-- Specific Attributes for NCP Server class
------------------------------------------

"LDAP Server" ATTRIBUTE ::=
{
	SyntaxID    SYN_DIST_NAME,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 20}
}

------------------------------------------
-- Specific Attributes for User class
------------------------------------------
"Internet EMail Address" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_PUBLIC_READ, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {0 9 2342 19200300 100 1 3}
}

"LDAP:searchReferralUsage" ATTRIBUTE ::=
{
	SyntaxID                SYN_INTEGER,
	Flags                   {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 23}
}

"LDAP:otherReferralUsage" ATTRIBUTE ::=
{
	SyntaxID                SYN_INTEGER,
	Flags                   {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 24}
}

------------------------------------------
-- New Object Classes
------------------------------------------
------------------------------------------

"LDAP Server" OBJECT-CLASS ::=
{
	Operation       ADD,
	SubClassOf      {"TOP"},
	Flags                   {DS_EFFECTIVE_CLASS},
	ContainedBy     {"Country", "Locality",
		    "Organizational Unit", "Organization"},
	NamedBy         {"CN"},
	MustContain     {"CN"},
	-- Order is not significant.
	MayContain  {
			"LDAP Host Server",					"LDAP Group",
			"LDAP Log Level",                "LDAP Screen Level",
			"LDAP Server Bind Limit",        "LDAP Server Idle Timeout",
			"LDAP TCP Port",
			"LDAP UDP Port",                 "LDAP SSL Port",
			"LDAP Log Filename",             "LDAP Backup Log Filename",
			"LDAP Log Size Limit"},
	ASN1ObjID   {2 16 840 1 113719 1 27 6 1}
}

"LDAP Server" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain  {
			"LDAP Enable TCP",              "LDAP Enable UDP"}
}

"LDAP Server" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain  {
			"LDAP Enable SSL",              "LDAP:keyMaterialName"}
}

"LDAP Server" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain  {
			"Version"}
}

"LDAP Server" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain {
			"searchSizeLimit",              "searchTimeLimit"
	}
}

"LDAP Server" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain {
			"ldapEnablePSearch",
			"ldapMaximumPSearchOperations",
			"ldapIgnorePSearchLimitsForEvents"
	}
}

"LDAP Group" OBJECT-CLASS ::=
{
	Operation   ADD,
	SubClassOf  {"TOP"},
	Flags       {DS_EFFECTIVE_CLASS},
	ContainedBy {"Country", "Locality",
		    "Organizational Unit", "Organization"},
	NamedBy     {"CN"},
	MustContain {"CN"},
	MayContain  {
			"LDAP Suffix",	   					"LDAP Referral",
			"LDAP Server List",	
			"LDAP Allow Clear Text Password",	"LDAP Anonymous Identity"},
	ASN1ObjID   {2 16 840 1 113719 1 27 6 2}
}

"LDAP Group" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain  {
			"LDAP ACL v11",							"Version"}
}
"LDAP Group" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain  {
			"LDAP:searchReferralUsage", "LDAP:otherReferralUsage"
			}
}

"LDAP Group" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain  {
			"LDAP Attribute Map v11",				"LDAP Class Map v11"}
}

"NCP Server" OBJECT-CLASS ::=
{
   Operation   MODIFY,
   MayContain  {"LDAP Server"}
}

"LDAP Group" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain  {
			"transitionGroupDN",
			"ldapAttributeList",				"ldapClassList"}
}


"Organizational Person" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain      {
		"Internet EMail Address"}
}

"Organizational Person" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain {
		"NSCP:employeeNumber"
	}
}

-- Since "Organizational Unit" and "Organization" are now inherited from "ndsLoginProperties",
-- they will always have "Public Key", "Private Key", "Network Address", "Login Time", and
-- "Last Login Time" option attributes.  There is no need to add them here anymore.

"extensionInfo" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE, DS_PUBLIC_READ},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 42}
}

"LDAP Server" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain  {"extensionInfo"}
}


"filteredReplicaUsage" ATTRIBUTE ::=
{
	SyntaxID                SYN_INTEGER,
	Flags                   {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 21}
}

"LDAP Server" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain  {"filteredReplicaUsage"}
}

"nonStdClientSchemaCompatMode" ATTRIBUTE ::=
{
	SyntaxID                SYN_BOOLEAN,
	Flags                   {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 45}
}

"LDAP Server" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain  {"nonStdClientSchemaCompatMode"}
}

"sslEnableMutualAuthentication" ATTRIBUTE ::=
{
 SyntaxID    SYN_BOOLEAN,
 Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
 ASN1ObjID   {2 16 840 1 113719 1 27 4 46}
}
 
"LDAP Server" OBJECT-CLASS ::=
{
 Operation       MODIFY,
 MayContain  {"sslEnableMutualAuthentication"}
}

END
