-- Schema Source:            ldapupdt.sch
-- Description:
-- %version:             36 %
-- %created_by:          troym %
-- %date_modified:       Fri Aug 10 14:32:39 2001 %

LDAPAuxExtentions DEFINITIONS ::=
BEGIN

-- Domain Naming for RFC 2247
-- dc, domain, and dcObject have been moved into base DS schema


-- PKI and Entrust attributes and class

-- was LDAPUserCertificate

"userCertificate" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE, DS_PUBLIC_READ},
	ASN1ObjID   {2 5 4 36}
}


-- was LDAP:caCertificate

"cACertificate" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE, DS_PUBLIC_READ},
	ASN1ObjID   {2 5 4 37}
}


-- was LDAP:ARL
"authorityRevocationList" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE, DS_PUBLIC_READ},
	ASN1ObjID   {2 5 4 38}
}

-- was LDAP:CRL
"certificateRevocationList" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE, DS_PUBLIC_READ},
	ASN1ObjID   {2 5 4 39}
}

"deltaRevocationList" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE, DS_PUBLIC_READ},
	ASN1ObjID   {2 5 4 53}
}


-- was LDAP:crossCertificatePair
"crossCertificatePair" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE, DS_PUBLIC_READ},
	ASN1ObjID   {2 5 4 40}
}

-- was Entrust:AttributeCertificate
"attributeCertificate" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE, DS_PUBLIC_READ},
	ASN1ObjID   {2 5 4 58}
}


------------------------------------------
-- New PKI and Entrust Auxiliary Classes
------------------------------------------

-- was CertificationAuthority
-- do we want to put the login stuff in pkiCA here or still add it to OU?

"pkiCA" OBJECT-CLASS ::=
{
	Operation       ADD,
	Flags           {DS_AUXILIARY_CLASS},
	MayContain      {
					"cACertificate",           "certificateRevocationList",
					"authorityRevocationList", "crossCertificatePair",
					"attributeCertificate",
					"Public Key",              "Private Key",
					"Network Address",
					"Login Time",              "Last Login Time"},
	ASN1ObjID   {2 5 6 22}
}

-- was entrustUser
"pkiUser" OBJECT-CLASS ::=
{
	Operation       ADD,
	Flags           {DS_AUXILIARY_CLASS},
	MayContain      {
					"userCertificate"
					},
	ASN1ObjID   {2 5 6 21}
}

-- remove cRLDistributionPoint from this file. (pki.sch will take care of it.)
-- was Entrust:CRLDistributionPoint
-- double check if caCert & ccPair should be part of cRLDistributionPoint
-- "cRLDistributionPoint" OBJECT-CLASS ::=
-- {
--	Operation       ADD,
-- 	SubClassOf      {"TOP"},
--	Flags           {DS_EFFECTIVE_CLASS},
--	ContainedBy     {"Country", "Locality", "Organizational Unit", 
--	                 "Organization", "SAS:Security"},
--	NamedBy         {"CN"},
--	MustContain     {"CN"},
--	MayContain      {
--					"authorityRevocationList",   "caCertificate",   
--					"certificateRevocationList", "crossCertificatePair",
--					"deltaRevocationList"},
--	ASN1ObjID   {2 5 6 19}
-- }

----------------------------------------
-- Definitions for NSCP LDAP products
----------------------------------------
-- was NSCP:mailAccessDomain
"NSCP:AmailAccessDomain" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	Flags                   {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113730 3 1 12}
}

-- was NSCP:mailAlternateAddress
"NSCP:AmailAlternateAddress" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	Flags                   {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113730 3 1 13}
}

-- Backward compatible with NetWare 5 SP1
"NSCP:mailAlternateAddress" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	ASN1ObjID   {2 16 840 1 113730 3 1 13}
}

-- was NSCP:mailAutoReplyMode
"NSCP:AmailAutoReplyMode" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	Flags                   {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113730 3 1 14}
}

-- was NSCP:mailAutoReplyText
"NSCP:AmailAutoReplyText" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	Flags                   {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113730 3 1 15}
}

-- was NSCP:mailDeliveryOption
"NSCP:AmailDeliveryOption" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	Flags                   {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113730 3 1 16}
}

-- was NSCP:mailForwardingAddress
"NSCP:AmailForwardingAddress" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	Flags                   {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113730 3 1 17}
}

-- Backward compatible with NetWare 5 SP1 schema
"NSCP:mailForwardingAddress" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	ASN1ObjID   {2 16 840 1 113730 3 1 17}
}

-- was NSCP:mailHost
"NSCP:AmailHost" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	Flags                   {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113730 3 1 18}
}

-- Backward compatible with NetWare 5 SP1
"NSCP:mailHost" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	ASN1ObjID   {2 16 840 1 113730 3 1 18}
}

-- was NSCP:mailMessageStore
"NSCP:AmailMessageStore" ATTRIBUTE ::=
{
	SyntaxID                SYN_CE_STRING,
	Flags                   {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113730 3 1 19}
}

-- was NSCP:mailProgramDeliveryInfo
"NSCP:AmailProgramDeliveryInfo" ATTRIBUTE ::=
{
	SyntaxID                SYN_CE_STRING,
	Flags                   {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 3 1 20}
}

-- was NSCP:mailQuota
"NSCP:AmailQuota" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	Flags                   {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 3 1 21}
}

"NSCP:mailRoutingAddress" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	Flags                   {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113730 3 1 47}
}

-- was NSCP:nsLicensedFor
"NSCP:AnsLicensedFor" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	Flags                   {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113730 3 1 36}
}

-- was NSCP:nsLicenseStartTime
"NSCP:AnsLicenseStartTime" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	Flags                   {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113730 3 1 37}
}

-- was NSCP:nsLicenseEndTime
"NSCP:AnsLicenseEndTime" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	Flags                   {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113730 3 1 38}
}
"NSCP:nsaclrole" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	ASN1ObjID   {2 16 840 1 113730 3 1 192}
}

"NSCP:nscreator" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	ASN1ObjID   {2 16 840 1 113730 3 1 195}
}

"NSCP:nsflags" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	ASN1ObjID   {2 16 840 1 113730 3 1 194}
}

"NSCP:nsnewsACL" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	ASN1ObjID   {2 16 840 1 113730 3 1 191}
}

"NSCP:nsprettyname" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	ASN1ObjID   {2 16 840 1 113730 3 1 193}
}

"NSCP:subtreeACI" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	ASN1ObjID   {2 16 840 1 113730 3 1 69}
}

-- map NSCP mgcomponent to this
"NSCP:ngcomponentCIS" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	ASN1ObjID   {2 16 840 1 113730 3 1 196}
}

"NSCP:adminURL" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	ASN1ObjID   {2 16 840 1 113730 3 1 75}
}

"NSCP:administratorContactInfo" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	ASN1ObjID   {2 16 840 1 113730 3 1 74}
}

"NSCP:installationTimeStamp" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	ASN1ObjID   {2 16 840 1 113730 3 1 73}
}

"NSCP:serverHostName" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	ASN1ObjID   {2 16 840 1 113730 3 1 76}
}

"NSCP:serverProductName" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	ASN1ObjID   {2 16 840 1 113730 3 1 71}
}

"NSCP:serverRoot" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	ASN1ObjID   {2 16 840 1 113730 3 1 70}
}

"NSCP:serverVersionNumber" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	ASN1ObjID   {2 16 840 1 113730 3 1 72}
}

"NSCP:mgrpRFC822mailmember" ATTRIBUTE ::=
{
	SyntaxID                SYN_CI_STRING,
	ASN1ObjID   {2 16 840 1 113730 3 1 30}
}

-- Aux Class definitions for NetScape products

"strongAuthenticationUser" OBJECT-CLASS ::=
{
	Operation       ADD,
	Flags           {DS_AUXILIARY_CLASS},
	MayContain      {
					"userCertificate"},
	ASN1ObjID   {2 5 6 15}
}

"NSCP:mailRecipient" OBJECT-CLASS ::=
{
	Operation       ADD,
	Flags           {DS_AUXILIARY_CLASS},
	MayContain      {
					"NSCP:AmailAccessDomain",        "NSCP:AmailAlternateAddress",
					"NSCP:AmailAutoReplyMode",       "NSCP:AmailAutoReplyText",
					"NSCP:AmailDeliveryOption",      "NSCP:AmailForwardingAddress",
					"NSCP:AmailHost",                "NSCP:AmailMessageStore",
					"NSCP:AmailProgramDeliveryInfo", "NSCP:AmailQuota"
					},
	ASN1ObjID   {2 16 840 1 113730 3 2 3}
}


"NSCP:mailRecipient" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain {
		"NSCP:mailRoutingAddress", 		"Internet EMail Address",
		"CN",							"UniqueID",
		"Description"
	}
}


"NSCP:nsLicenseUser" OBJECT-CLASS ::=
{
	Operation       ADD,
	Flags           {DS_AUXILIARY_CLASS},
	MayContain      {
					"NSCP:AnsLicensedFor",			"NSCP:AnsLicenseStartTime",
					"NSCP:AnsLicenseEndTime"},
	ASN1ObjID   {2 16 840 1 113730 3 2 7}
}


-- NSCP effective Object Classes

-- new, replaced nginfo2 , map LDAP nginfo to it
"NSCP:nginfo3" OBJECT-CLASS ::=
{
	Operation   ADD,
	SubClassOf  {"Top"},
	Flags       {DS_EFFECTIVE_CLASS, DS_CONTAINER_CLASS},
	ContainedBy {"Country", "Locality",
		    "Organizational Unit", "Organization"},
	NamedBy     {"NSCP:ngcomponentCIS"},
	MustContain {"NSCP:ngcomponentCIS"},
	MayContain  {
					"NSCP:nsaclrole",                       "NSCP:nscreator",
					"NSCP:nsflags",                         "NSCP:nsnewsACL",
					"NSCP:nsprettyname",                    "NSCP:subtreeACI"},
	ASN1ObjID   {2 16 840 1 113730 3 2 26}
}

"NSCP:NetscapeServer5" OBJECT-CLASS ::=
{
	Operation   ADD,
	SubClassOf  {"Server"},
	Flags       {DS_EFFECTIVE_CLASS, DS_CONTAINER_CLASS},
	ContainedBy {"Country", "Locality",
				  "Organizational Unit", "Organization"},
	MayContain  {
					"NSCP:adminURL",                "NSCP:administratorContactInfo",
					"NSCP:installationTimeStamp",   "NSCP:serverHostName",
					"NSCP:serverProductName",               "NSCP:serverRoot",
					"NSCP:serverVersionNumber"},
	ASN1ObjID   {2 16 840 1 113730 3 2 10}
}

"NSCP:NetscapeMailServer5" OBJECT-CLASS ::=
{
	Operation   ADD,
	SubClassOf  {"NSCP:NetscapeServer5"},
	Flags       {DS_EFFECTIVE_CLASS, DS_CONTAINER_CLASS},
	ContainedBy	{"NSCP:NetscapeServer5"},
	ASN1ObjID   {2 16 840 1 113730 3 2 24}
}

-- was NSCP:mailGroup5 & previously NSCP:mailGroup
"NSCP:mailGroup1" OBJECT-CLASS ::=
{
	Operation   ADD,
	SubClassOf  {"Group"},
	Flags       {DS_EFFECTIVE_CLASS, DS_CONTAINER_CLASS},
	ContainedBy {"Country", "Locality",
				  "Organizational Unit", "Organization"},
	ASN1ObjID   {2 16 840 1 113730 3 2 4}
}

"NSCP:mailGroup1" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain  {
					"Internet EMail Address",
					
					-- Backward compatible with NetWare 5 SP1
					"NSCP:mailAlternateAddress",
					"NSCP:mailForwardingAddress",					"NSCP:mailHost",
					
					-- Attributes for SKADS
					"NSCP:mgrpRFC822mailmember",
					"NSCP:AmailAlternateAddress",					"NSCP:AmailForwardingAddress",
					"NSCP:AmailHost"}
}


-- RFC 2256
"knowledgeInformation" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  1,
	UpperBound  32768,
	ASN1ObjID   {2 5 4 2}
}

"searchGuide" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 5 4 14}
}

"businessCategory" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  1,
	UpperBound  128,
	ASN1ObjID   {2 5 4 15}
}

"telexNumber" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 5 4 21}
}

"teletexTerminalIdentifier" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 5 4 22}
}

"x121Address" ATTRIBUTE ::=
{
	SyntaxID    SYN_NU_STRING,
	Flags       {DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  1,
	UpperBound  15,
	ASN1ObjID   {2 5 4 24}
}

"internationaliSDNNumber" ATTRIBUTE ::=
{
	SyntaxID    SYN_NU_STRING,
	Flags       {DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  1,
	UpperBound  16,
	ASN1ObjID   {2 5 4 25}
}

"registeredAddress" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 5 4 26}
}

"destinationIndicator" ATTRIBUTE ::=
{
	SyntaxID    SYN_PR_STRING,
	Flags       {DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  1,
	UpperBound  128,
	ASN1ObjID   {2 5 4 27}
}

"preferredDeliveryMethod" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 5 4 28}
}

"presentationAddress" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 5 4 29}
}

"supportedApplicationContext" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 5 4 30}
}

"generationQualifier" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  1,
	UpperBound  32768,
	ASN1ObjID   {2 5 4 44}
}

"x500UniqueIdentifier" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 5 4 45}
}

"dnQualifier" ATTRIBUTE ::=
{
	SyntaxID    SYN_PR_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 5 4 46}
}

"enhancedSearchGuide" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 5 4 47}
}

"protocolInformation" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 5 4 48}
}

"houseIdentifier" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  1,
	UpperBound  32768,
	ASN1ObjID   {2 5 4 51}
}

"supportedAlgorithms" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 5 4 52}
}

"dmdName" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  1,
	UpperBound  32768,
	ASN1ObjID   {2 5 4 54}
}

"roomNumber" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {0 9 2342 19200300 100 1 6}
}

-- The lenght of "NSCP:memberCertificateDescription" is too long for NDS. So, I trim it down to ..
-- .. NSCP:memberCertificateDesc. The maximum number of attribute chars for NDS are 32.
"NSCP:memberCertificateDesc" ATTRIBUTE ::=
{
	SyntaxID    SYN_CE_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113730 3 1 199}
}

"applicationProcess" OBJECT-CLASS ::=
{
	Operation   ADD,
	SubClassOf  {"Top"},
	Flags       {DS_EFFECTIVE_CLASS, DS_CONTAINER_CLASS},
	ContainedBy {"Country", "Locality",
					"Organizational Unit", "Organization"},
	NamedBy		{"CN"},
	MustContain	{"CN"},
	MayContain  {
				   "See Also",									"OU",
					"L",											"Description"},
	ASN1ObjID   {2 5 6 11}
}

"applicationEntity" OBJECT-CLASS ::=
{
	Operation   ADD,
	SubClassOf  {"Top"},
	Flags       {DS_EFFECTIVE_CLASS, DS_CONTAINER_CLASS},
	ContainedBy {"Country", "Locality",
					"Organizational Unit", "Organization"},
	NamedBy		{"CN"},
	MustContain	{"presentationAddress", "CN"},
	MayContain  {
					"supportedApplicationContext",		"See Also",
					"OU",											"O",
					"L",											"Description"},
	ASN1ObjID   {2 5 6 12}
}

"dSA" OBJECT-CLASS ::=
{
	Operation   ADD,
	SubClassOf  {"applicationEntity"},
	Flags       {DS_EFFECTIVE_CLASS, DS_CONTAINER_CLASS},
	ContainedBy {"Country", "Locality",
					"Organizational Unit", "Organization"},
	MayContain  {
					"knowledgeInformation"},
	ASN1ObjID   {2 5 6 13}
}

"certificationAuthority" OBJECT-CLASS ::=
{
	Operation   ADD,
	Flags       {DS_AUXILIARY_CLASS},
	MustContain	{"authorityRevocationList", "certificateRevocationList",
					"cACertificate"},
	MayContain  {
					"crossCertificatePair"},
	ASN1ObjID   {2 5 6 16}
}

"userSecurityInformation" OBJECT-CLASS ::=
{
	Operation   ADD,
	Flags       {DS_AUXILIARY_CLASS},
	MayContain  {
					"supportedAlgorithms"},
	ASN1ObjID   {2 5 6 18}
}

"NSCP:groupOfCertificates" OBJECT-CLASS ::=
{
	Operation   ADD,
	SubClassOf  {"Top"},
	Flags       {DS_EFFECTIVE_CLASS, DS_CONTAINER_CLASS},
	ContainedBy {"Country", "Locality",
					"Organizational Unit", "Organization"},
	NamedBy		{"CN"},
	MustContain	{"CN"},
	MayContain  {
					"NSCP:memberCertificateDesc",						"businessCategory",
					"Description",											"O",
					"OU",														"Owner",
					"See Also"},
	ASN1ObjID   {2 16 840 1 113730 3 2 31}
}

"Organizational Person" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain {
		"destinationIndicator",				"internationaliSDNNumber",
		"preferredDeliveryMethod",			"registeredAddress",
		"teletexTerminalIdentifier",		"telexNumber",
		"x121Address"
	}
}

"Organizational Person" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain {
		"businessCategory",					"roomNumber",
		"x500UniqueIdentifier"
	}
}

"Organization" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain {
		"x121Address",				"registeredAddress",
		"destinationIndicator",		 "preferredDeliveryMethod",
		"telexNumber",				 "teletexTerminalIdentifier",
		"internationaliSDNNumber",	 "BusinessCategory",
		"searchGuide"
	}
}

"Organizational Unit" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain {
		"x121Address",				"registeredAddress",
		"destinationIndicator",		 "preferredDeliveryMethod",
		"telexNumber",				 "teletexTerminalIdentifier",
		"internationaliSDNNumber",	 "BusinessCategory",
		"searchGuide"
	}
}

"Organizational Role" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain {
		"x121Address",				"registeredAddress",
		"destinationIndicator",		 "preferredDeliveryMethod",
		"telexNumber",				 "teletexTerminalIdentifier",
		"internationaliSDNNumber"
	}
}

"group" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain  {
					"businessCategory"}
}

"dmd" OBJECT-CLASS ::=
{
	Operation   ADD,
	SubClassOf  {"Top","ndsLoginProperties"},
	Flags       {DS_AUXILIARY_CLASS},
	MustContain	{"dmdName"},
	MayContain  {
					"searchGuide",
					"See Also", 					"businessCategory",
					"x121Address", 				"registeredAddress",
					"destinationIndicator",		"preferredDeliveryMethod",
					"telexNumber", 				"teletexTerminalIdentifier",
					"Telephone Number", 			"internationaliSDNNumber",
					"Facsimile Telephone Number",	"SA",
					"Postal Office Box", 			"Postal Code",
					"Postal Address", 			"Physical Delivery Office Name",
					"L", 					"Description"},
	ASN1ObjID   {2 5 6 20}
}

"associatedName" ATTRIBUTE ::=
{
	SyntaxID    SYN_DIST_NAME,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {0 9 2342 19200300 100 1 38}
}

"domain" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain  {
					"searchGuide",					"O",
					"See Also", 					"businessCategory",
					"x121Address", 					"registeredAddress",
					"destinationIndicator",			"preferredDeliveryMethod",
					"telexNumber", 					"teletexTerminalIdentifier",
					"Telephone Number", 			"internationaliSDNNumber",
					"Facsimile Telephone Number",	"SA",
					"Postal Office Box", 			"Postal Code",
					"Postal Address", 				"Physical Delivery Office Name",
					"L", 							"associatedName",
					"Description"}
}

"country" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain  {"searchGuide"}
}

"Locality" OBJECT-CLASS ::=
{
	Operation       MODIFY,
	MayContain  {"searchGuide"}
}

"person" OBJECT-CLASS ::=
{
	Operation		MODIFY,
	MayContain	{
					"Full Name", 	"Given Name",
					"initials",		"uniqueID"
				}
}

"Group" OBJECT-CLASS ::=
{
	Operation		MODIFY,
	MayContain	{"Member"}
}

"certificationAuthorityVer2" OBJECT-CLASS ::=
{
	Operation   ADD,
	Flags       {DS_AUXILIARY_CLASS},
	MustContain	{"authorityRevocationList", "certificateRevocationList", 
					"cACertificate"},
	MayContain  {"crossCertificatePair", "deltaRevocationList"},
	ASN1ObjID   {2 5 6 16 2}
}

END
