RFC2307NisSchemaExtensions DEFINITIONS ::=
BEGIN

"memberNisNetGroup" ATTRIBUTE ::=
{
	Operation		ADD,
	SyntaxID       SYN_CE_STRING,
	Flags          { DS_SYNC_IMMEDIATE},
   ASN1ObjID      {1 3 6 1 1 1 1 13} 
}

-- NetGroup Triple
-- rfc2307 defines a new syntax nisNetgroupTripleSyntax, which we cant define 
-- in NDS. So, using the bit string syntax instead
"nisNetGroupTriple" ATTRIBUTE ::=
{
	Operation		ADD,
   SyntaxID       SYN_OCTET_STRING,
	Flags          { DS_SYNC_IMMEDIATE},
   ASN1ObjID      {1 3 6 1 1 1 1 14} 
}


"ipServicePort" ATTRIBUTE ::=
{
	Operation		ADD,
	SyntaxID       SYN_INTEGER,
	Flags          { DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
   ASN1ObjID      {1 3 6 1 1 1 1 15} 
}

"ipServiceProtocol" ATTRIBUTE ::=
{
	Operation	   ADD,
	SyntaxID       SYN_CI_STRING,
	Flags          { DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound		1,
	UpperBound		32768,
   ASN1ObjID      {1 3 6 1 1 1 1 16} 
}

"ipProtocolNumber" ATTRIBUTE ::=
{
	Operation		ADD,
	SyntaxID       SYN_INTEGER,
	Flags          { DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
   ASN1ObjID      {1 3 6 1 1 1 1 17} 
}

"oncRpcNumber" ATTRIBUTE ::=
{
	Operation		ADD,
	SyntaxID       SYN_INTEGER,
	Flags          { DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
   ASN1ObjID      {1 3 6 1 1 1 1 18} 
}

-- IP address as a dotted decimal, eg 192.168.1.1, omitting leading zeros
"ipHostNumber" ATTRIBUTE ::=
{
	Operation		ADD,
	SyntaxID       SYN_CI_STRING,
	Flags          { DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound		1,
	UpperBound		128,
   ASN1ObjID      {1 3 6 1 1 1 1 19} 
}

-- IP network as a dotted decimal, eg. 192.168, omitting leading zeros
"ipNetworkNumber" ATTRIBUTE ::=
{
	Operation		ADD,
	SyntaxID       SYN_CI_STRING,
	Flags          { DS_SIZED_ATTR, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound		1,
	UpperBound		128,
   ASN1ObjID      {1 3 6 1 1 1 1 20} 
}

-- IP netmask as a dotted decimal, eg. 255.255.255.0, omitting leading zeros
"ipNetmaskNumber" ATTRIBUTE ::=
{
	Operation		ADD,
	SyntaxID       SYN_CI_STRING,
	Flags          { DS_SIZED_ATTR, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound		1,
	UpperBound		128,
   ASN1ObjID      {1 3 6 1 1 1 1 21} 
}

-- MAC address in maximal, colon separated hex notation, eg. 00:00:92:90:ee:e2
"macAddress" ATTRIBUTE ::=
{
	Operation		ADD,
	SyntaxID       SYN_CI_STRING,
	Flags          { DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound		1,
	UpperBound		128,
   ASN1ObjID      {1 3 6 1 1 1 1 22} 
}

-- rpc.bootparamd parameter
-- rfc2307 defines a new syntax bootParameterSyntax, which we cant define in 
-- NDS. So, using the bit string syntax instead
"bootParameter" ATTRIBUTE ::=
{
	Operation		ADD,
   SyntaxID       SYN_OCTET_STRING,
	Flags          { DS_SYNC_IMMEDIATE},
   ASN1ObjID      {1 3 6 1 1 1 1 23} 
}

-- Boot image name
"bootFile" ATTRIBUTE ::=
{
	Operation		ADD,
	SyntaxID       SYN_CE_STRING,
	Flags          { DS_SYNC_IMMEDIATE},
   ASN1ObjID      {1 3 6 1 1 1 1 24} 
}

"nisMapName" ATTRIBUTE ::=
{
	Operation	   ADD,
	SyntaxID       SYN_CI_STRING,
	Flags          { DS_SIZED_ATTR, DS_SYNC_IMMEDIATE },
	LowerBound		1,
	UpperBound		64,
   ASN1ObjID      {1 3 6 1 1 1 1 26} 
}

"nisMapEntry" ATTRIBUTE ::=
{
	Operation		ADD,
	SyntaxID       SYN_CE_STRING,
	Flags          { DS_SIZED_ATTR, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound		1,
	UpperBound		1024,
   ASN1ObjID      {1 3 6 1 1 1 1 27} 
}

-- Adding ATTRIBUTE manager. 
-- This is present in the base schema of newer versions of NDS.
"manager" ATTRIBUTE ::=
{
	Operation		ADD,
	SyntaxID       SYN_DIST_NAME,
	Flags          { DS_SYNC_IMMEDIATE},
   ASN1ObjID      {0 9 2342 19200300 100 1 10} 
}

-- Abstraction an Internet Protocol service. Maps an IP port and protocol 
-- (such as tcp or udp) to one or more names; the distinguished value of the 
-- cn attribute denotes the service's canonical name
"ipService" OBJECT-CLASS ::=
{
	Operation   ADD,
	Flags       { DS_EFFECTIVE_CLASS },
	SubClassOf  { "TOP" },
	ContainedBy { "Organization" , "Organizational Unit" },
	NamedBy     { "CN" , "ipServiceProtocol"},
	MustContain { "CN", "ipServicePort", "ipServiceProtocol" },
	MayContain  { "Description" },
   ASN1ObjID   {1 3 6 1 1 1 2 3} 
}

-- Abstraction of an IP protocol. Maps a protocol number to one or more names.
-- The distinguished value of the cn attribute denotes the protocol's 
-- canonical name
"ipProtocol" OBJECT-CLASS ::=
{
	Operation   ADD,
	Flags       { DS_EFFECTIVE_CLASS },
	SubClassOf  { "TOP" },
	ContainedBy { "Organization" , "Organizational Unit" },
	NamedBy     { "CN" },
	MustContain { "CN", "ipProtocolNumber" },
	MayContain  { "Description" },
   ASN1ObjID   {1 3 6 1 1 1 2 4} 
}

-- Abstraction of an Open Network Computing (ONC) [RFC1057] Remote Procedure 
-- Call (RPC) binding. This class maps an ONC RPC number to a name. The 
-- distinguished value of the cn attribute denotes the RPC service's 
-- canonical name
"oncRpc" OBJECT-CLASS ::=
{
	Operation   ADD,
	Flags       { DS_EFFECTIVE_CLASS },
	SubClassOf  { "TOP" },
	ContainedBy { "Organization" , "Organizational Unit" },
	NamedBy     { "CN" },
	MustContain { "CN", "oncRpcNumber" },
	MayContain  { "Description" },
   ASN1ObjID   {1 3 6 1 1 1 2 5} 
}

-- Abstraction of a host, an IP device. The distinguished value of the cn 
-- attribute denotes the host's canonical name. 
-- According to RFC 2307 this is an Auxiliary class and device should be used 
-- as Structural class. Currently we won't be able to do that so we are making
-- this as structural itself.
"ipHost" OBJECT-CLASS ::=
{
	Operation   ADD,
	Flags       { DS_EFFECTIVE_CLASS },
	SubClassOf  { "TOP", "Device" },
	ContainedBy { "Organization" , "Organizational Unit" },
	NamedBy     { "CN" },
	MustContain { "ipHostNumber" },
	MayContain  { "manager" },
   ASN1ObjID   {2 16 840 1 113719 1 167 6 4 1} 
}

-- Abstraction of a network. The distinguished value of the cn attribute 
-- denotes the network's canonical name
"ipNetwork" OBJECT-CLASS ::=
{
	Operation   ADD,
	Flags       { DS_EFFECTIVE_CLASS },
	SubClassOf  { "TOP" },
	ContainedBy { "Organization" , "Organizational Unit" },
	NamedBy     { "CN" },
	MustContain { "CN", "ipNetworkNumber" },
	MayContain  { "Description", "L", "manager", "ipNetmaskNumber" },
   ASN1ObjID   {1 3 6 1 1 1 2 7} 
}

-- Abstraction of a netgroup. May refer to other netgroups
"nisNetgroup" OBJECT-CLASS ::=
{
	Operation   ADD,
	Flags       { DS_EFFECTIVE_CLASS },
	SubClassOf  { "TOP" },
	ContainedBy { "Organization" , "Organizational Unit" },
	NamedBy     { "CN" },
	MustContain { "CN" },
	MayContain  { "Description", "nisNetgroupTriple", "memberNisNetgroup" },
   ASN1ObjID   {1 3 6 1 1 1 2 8} 
}


-- An entry in a NIS map
"nisObject" OBJECT-CLASS ::=
{
	Operation   ADD,
	Flags       { DS_EFFECTIVE_CLASS },
	SubClassOf  { "TOP" },
	ContainedBy { "Organization" , "Organizational Unit" },
	NamedBy     { "CN", "nisMapName" },
	MustContain { "CN", "nisMapEntry", "nisMapName" },
	MayContain  { "Description" },
   ASN1ObjID   {1 3 6 1 1 1 2 10} 
}

-- A device with a MAC address
-- According to RFC 2307 this is an Auxiliary class and device should be used 
-- as Structural class. Currently we won't be able to do that so we are making
-- this as structural itself.
"ieee802Device" OBJECT-CLASS ::=
{
	Operation   ADD,
	Flags       { DS_EFFECTIVE_CLASS },
	SubClassOf  { "TOP", "Device" },
	ContainedBy { "Organization" , "Organizational Unit" },
	NamedBy     { "CN" },
	MayContain  { "macAddress" },
   ASN1ObjID   {2 16 840 1 113719 1 167 6 5 1} 
}

-- A device with boot parameters
-- According to RFC 2307 this is an Auxiliary class and device should be used 
-- as Structural class. Currently we won't be able to do that so we are making
-- this as structural itself.
"bootableDevice" OBJECT-CLASS ::=
{
	Operation   ADD,
	Flags       { DS_EFFECTIVE_CLASS },
	SubClassOf  { "TOP", "Device" },
	ContainedBy { "Organization" , "Organizational Unit" },
	NamedBy     { "CN" },
	MayContain  { "bootFile", "bootParameter" },
   ASN1ObjID   {2 16 840 1 113719 1 167 6 6 1} 
}

END
